# 又一个微信聊天机器人横空出世了，人人可用！


之前给大家分享过一个微信机器人：[一个15分钟的视频，教你用Python创建自己的微信聊天机器人！](http://t.cn/A66p30bI)

但是之前这个机器人，需要基于网页版才能用；然而很多朋友的微信，是不能登录网页版微信的。

> 有没有一种微信机器人，任何人的微信都可以用，不需要网页微信功能呢？


在经过技术检索和开发以后，支持所有微信使用的：**PyOfficeRobot**来啦~

## 1、安装PyOfficeRobot

1行命令，安装PyOfficeRobot这个库
```
pip install -i https://pypi.tuna.tsinghua.edu.cn/simple PyOfficeRobot -U
```

## 2、视频教程

- 💻[001-项目发布](https://www.bilibili.com/video/BV1Xa411u7yU)

- [002-发消息](https://www.bilibili.com/video/BV1Jt4y1j7F1)

- [003-发文件](https://www.bilibili.com/video/BV1te4y1y7Ro)

- [004-根据关键词，自动回复](https://www.bilibili.com/video/BV1fV4y1M7ju)

- ⭐持续更新中，交流群：[点我加入](http://www.python4office.cn/wechat-group/)


## 3、功能Demo

我最近开源了这个库的全部源代码，功能正在开发中，欢迎大家参与开发~

- [演示代码](https://github.com/CoderWanFeng/PyOfficeRobot/tree/main/demo)

---

![](https://www.python-office.com/api/img-cdn/python-office/find_excel_data/group.jpg)
